package com.loit.getway.config;

import org.springframework.beans.factory.InitializingBean;
import org.springframework.boot.context.properties.ConfigurationProperties;
import org.springframework.stereotype.Component;

import java.util.ArrayList;
import java.util.List;
import java.util.regex.Pattern;

/**
 * @author wbh
 * @createDate 2020-03-23
 */
@Component
@ConfigurationProperties(prefix = "auth-skip")
public class AuthSkipUrlsProperties implements InitializingBean {

    private static final String NORMAL = "(\\w|\\d|-)+";
    private List<Pattern> urlPatterns = new ArrayList<>();
    private List<Pattern> serverPatterns = new ArrayList<>();
    private List<String> dataWorksServers;
    private List<String> apiUrls;
    private List<String> noUserServers;
    private List<String> noUserUri;
	private List<String> commonUri;

    /**
     * This {@link AuthSkipUrlsProperties} init
     */
    @Override
    public void afterPropertiesSet() {
        dataWorksServers.stream().map(d -> d.replace("*", NORMAL)).map(Pattern::compile).forEach(serverPatterns::add);
        apiUrls.stream().map(s -> s.replace("*", NORMAL)).map(Pattern::compile).forEach(urlPatterns::add);
    }

	public List<Pattern> getUrlPatterns() {
		return urlPatterns;
	}

	public void setUrlPatterns(List<Pattern> urlPatterns) {
		this.urlPatterns = urlPatterns;
	}

	public List<Pattern> getServerPatterns() {
		return serverPatterns;
	}

	public void setServerPatterns(List<Pattern> serverPatterns) {
		this.serverPatterns = serverPatterns;
	}

	public List<String> getDataWorksServers() {
		return dataWorksServers;
	}

	public void setDataWorksServers(List<String> dataWorksServers) {
		this.dataWorksServers = dataWorksServers;
	}

	public List<String> getApiUrls() {
		return apiUrls;
	}

	public void setApiUrls(List<String> apiUrls) {
		this.apiUrls = apiUrls;
	}

	public List<String> getNoUserServers() {
		return noUserServers==null?new ArrayList<>():noUserServers;
	}

	public void setNoUserServers(List<String> noUserServers) {
		this.noUserServers = noUserServers;
	}

	public List<String> getNoUserUri() {
		return noUserUri==null?new ArrayList<>():noUserUri;
	}

	public void setNoUserUri(List<String> noUserUri) {
		this.noUserUri = noUserUri;
	}

	public List<String> getCommonUri() {
		return commonUri==null?new ArrayList<>():commonUri;
	}

	public void setCommonUri(List<String> commonUri) {
		this.commonUri = commonUri;
	}
    
}