package com.loit.getway.utils;

import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.server.reactive.ServerHttpRequest;
import org.springframework.stereotype.Component;
import org.springframework.web.client.RestTemplate;

import com.loit.getway.config.GateWayConfig;
import com.loit.getway.dto.ClientAccessTokenUserDTO;


@Component("clientUserUtil")
public class ClientUserUtil {
    @Autowired
    private RestTemplate restTemplate;
    @Autowired
    private GateWayConfig gateWayConfig;

    private final  Long defaultAccessTokenKillTimeOut = 3600L;

	protected Logger logger = LoggerFactory.getLogger(getClass());

    /**
     * 获取登录用户id-从登录服务器获取
     */
    public String getCasServerUserId(ServerHttpRequest request, String accessToken){
        logger.debug("3.网关获取的令牌={}", accessToken);
    	if(accessToken==null||accessToken.length()==0) {
            return null;
        }
    	long startTime=System.currentTimeMillis();

        // PC端和移动端accessToken 在第一次从单点获取用户信息时做了缓存，此处可以直接从缓存获取accessToken取得相应的userId
        String userId = (String) CacheUtils.get(accessToken);
        logger.debug("4.缓存获取userId={}",userId);
        if(StringUtils.isNotEmpty(userId)){
            //读取单点配置的accessToken过期时间
            Object timeObject = RedisUtil.get("CAS_ACCESS_TOKEN_TIME_OUT");
            Long timeOut = timeObject != null ? Long.parseLong(timeObject.toString()) : defaultAccessTokenKillTimeOut;
        }

        if(StringUtils.isNotEmpty(userId)){
            return userId;
        }

        String url = gateWayConfig.profileUrl(request).replace("{accessToken}", accessToken);
        logger.debug("6.登录服务器获取userId的url={}", url);
        ClientAccessTokenUserDTO accessTokenUserDTO = restTemplate.getForObject(url, ClientAccessTokenUserDTO.class);
        userId = accessTokenUserDTO.getId();
        logger.debug("7.登录服务器获取userId={}", userId);

		long endTime=System.currentTimeMillis();
		float excTime=(float)(endTime-startTime);
        logger.info("userId: {} 耗时: {}ms 获取userId的url: {}", userId, excTime, url);

        return userId;
    }
}
